Flip enum

Represents the flip state of a rectangle, or, in other words, if the box is flipped horizontally, vertically, or diagonally.

Inheritance
Available extensions

Values

none → const Flip

No flipping, the rect stays as it is, not allowing any flipping.

horizontal → const Flip

Flipped horizontally. When a rect is flipped on x-axis, the left side becomes right and vice versa.

vertical → const Flip

Flipped vertically. When a rect is flipped on y-axis, the top side becomes bottom and vice versa.

diagonal → const Flip

Flipped diagonally. When a rect is flipped on both axis, the top left becomes bottom right and vice versa.

This flip is uniform, meaning that flipping top-left with bottom-right will result in the same rect as flipping bottom-left with top-right.

Properties

hashCode → int
The hash code for this object.
no setterinherited
horizontalValue → double
The horizontal value of the flip. Negative if it is flipped horizontally, positive otherwise.
no setter
index → int
A numeric identifier for the enumerated value.
no setterinherited
isDiagonal → bool
Whether the flip is diagonal.
no setter
isFlipped → bool
Whether it is flipped or not.
no setter
isFlippingOnX → bool
Whether the flip is on x-axis, meaning that it is either horizontal or diagonal.
no setter
isFlippingOnY → bool
Whether the flip is on y-axis, meaning that it is either vertical or diagonal.
no setter
isHorizontal → bool
Whether the flip is horizontal.
no setter
isNotFlipped → bool
Whether it is not flipped or is.
no setter
isVertical → bool
Whether the flip is vertical.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
prettify → String
Displayable representation of the Flip value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalValue → double
The vertical value of the flip. Negative if it is flipped vertically, positive otherwise.
no setter

Methods

influencedBy(Flip other) → Flip
Creates a new Flip by combining this Flip with the given other flip making the resulting flip influenced by other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator *(Flip other) → dynamic
Creates a new Flip by combining this Flip with the given. See influencedBy for more details.
operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<Flip>
A constant List of the values in this enum, in order of their declaration.